contexttools.detach_key_signature_marks_attached_to_component
=============================================================

.. autofunction:: abjad.tools.contexttools.detach_key_signature_marks_attached_to_component.detach_key_signature_marks_attached_to_component
